@@ -207,7 +207,8 @@ class GoalCategory(Enum):
     behaviors, and their interactions with objects in the environment.
 
     This goal category is only used for the **passive/VoE agent tasks**. All
-    interactive agent tasks will use the `retrieval` goal category.
+    interactive agent tasks will use either the `retrieval` or
+    `multi retrieval` goal category.
 
     Notes
     -----
@@ -217,6 +218,30 @@ class GoalCategory(Enum):
     `score`.
     """
 
+    IMITATION = "imitation"
+    """
+    In a trial that has an imitation goal, you must imitate the actions of
+    another agent in the scene to find and pickup a target object. Executing
+    the same actions, on the same objects, in the same order, is of critical
+    importance; if you do not imitate the actions correctly, you will be
+    forced to end the scene (by calling end_scene, or using the END_SCENE
+    action), without achieving the reward. In MCS Evaluation 4 and onward, the
+    target object will always be a soccer ball (football), and, in MCS
+    Evaluation 6, the imitated actions will always be opening containers of
+    various colors and shapes (using the normal OpenObject action).
+
+    Notes
+    -----
+    At `oracle` metadata level, the `metadata` dict property of this
+    GoalMetadata object will contain a `target` property, which is a dict
+    containing the following parameters:
+
+    Parameters
+    ----------
+    id : string
+        The unique objectId of the target object to retrieve.
+    """
+
     INTUITIVE_PHYSICS = "intuitive physics"
     """
     In a trial that has an Intuitive Physics goal, you must sit and observe a
@@ -236,10 +261,32 @@ class GoalCategory(Enum):
     `report`.
     """
 
+    PASSIVE = "passive"
+    """
+    In a trial that has a Passive goal, you must sit and observe a scene as
+    action unfolds in your camera's viewport, and then decide whether the scene
+    is "plausible" or "implausible". These trials will demand a "common sense"
+    understanding of places, objects, or agency. This goal category covers all
+    passive scenes that do not fall under the "agents" or "intuitive physics"
+    categories.
+
+    Notes
+    -----
+    You are required to call `controller.end_scene()` at the end of each scene
+    with a binary plausibility `rating` -- either 0 (implausible) or 1
+    (plausible) -- and a continuous plausibility `score` -- from 0.0
+    (completely implausible) to 1.0 (completely plausible). This is also
+    where you would submit any retrospective reporting on a per step basis via
+    `report`.
+    """
+
     RETRIEVAL = "retrieval"
     """
     In a trial that has a retrieval goal, you must find and pickup a target
-    object. This may involve exploring the scene, avoiding obstacles,
+    object. In MCS Evaluation 4 and onward, the target object will always be a
+    soccer ball (football).
+
+    This may involve exploring the scene, avoiding obstacles,
     interacting with objects (like closed containers) or agents, and tracking
     moving objects. These trials will demand a "common sense" understanding of
     self navigation (how to move and rotate yourself within a scene and around
@@ -247,14 +294,40 @@ class GoalCategory(Enum):
     containers), the basic physics of movement (kinematics, gravity, friction,
     etc.), and agency (identifying people and using them to achieve a goal).
 
+    Notes
+    -----
+    At `oracle` metadata level, the `metadata` dict property of this
+    GoalMetadata object will contain a `target` property, which is a dict
+    containing the following parameters:
+
     Parameters
     ----------
-    target.id : string
-        The objectId of the target object to retrieve.
-        Will only be available at `oracle` metadata level.
+    id : string
+        The unique objectId of the target object to retrieve.
+    """
 
-    target.info : list of strings
-        Human-readable information describing the target object needed for the
-        visualization interface.
+    MULTI_RETRIEVAL = "multi retrieval"
+    """
+    In a trial that has a multi retrieval goal, you must find and pickup one or
+    more target objects. In MCS Evaluation 4 and onward, the target object will
+    always be a soccer ball (football).
 
+    This may involve exploring the scene, avoiding obstacles,
+    interacting with objects (like closed containers) or agents, and tracking
+    moving objects. These trials will demand a "common sense" understanding of
+    self navigation (how to move and rotate yourself within a scene and around
+    obstacles), object interaction (how objects work, including opening
+    containers), the basic physics of movement (kinematics, gravity, friction,
+    etc.), and agency (identifying people and using them to achieve a goal).
+
+    Notes
+    -----
+    At `oracle` metadata level, the `metadata` dict property of this
+    GoalMetadata object will contain a `targets` property, which is a list of
+    dicts that each contain the following parameters:
+
+    Parameters
+    ----------
+    id : string
+        The unique objectId of one of the target objects to retrieve.
     """
