@@ -94,7 +94,7 @@ class Parameter:
     def __init__(self, config: ConfigManager):
         self.config = config
 
-    def wrap_step(self, **kwargs) -> Dict:
+    def wrap_step(self, output_folder, **kwargs) -> Dict:
         # whether or not to randomize segmentation mask colors
         metadata_tier = self.config.get_metadata_tier()
         consistent_colors = (metadata_tier == MetadataTier.ORACLE)
@@ -107,13 +107,19 @@ class Parameter:
             renderObjectImage=self.config.is_object_masks_enabled(),
             snapToGrid=False,
             consistentColors=consistent_colors,
+            recordTopDown=(self.config.is_video_enabled() and
+                           self.config.is_top_down_camera()),
+            topDownImagePath=output_folder,
             **kwargs
         )
 
-    def build_ai2thor_step(self, **kwargs) -> Tuple:
+    def build_ai2thor_step(self, output_path, **kwargs) -> Tuple:
         action, params = self._validate_and_convert_params(**kwargs)
         action = self._mcs_action_to_ai2thor_action(action)
-        wrapped_step = self.wrap_step(action=action, **params)
+        wrapped_step = self.wrap_step(
+            output_folder=output_path,
+            action=action,
+            **params)
         return wrapped_step, params
 
     def _convert_y_image_coord_for_unity(self, y_coord: int) -> int:
