@@ -8,7 +8,7 @@ from machine_common_sense.config_manager import (ActionConfig,
                                                  AgentSettings,
                                                  ChangeMaterialConfig,
                                                  ConfigManager, ForceConfig,
-                                                 Goal, MetadataTier,
+                                                 Goal, LidConfig, MetadataTier,
                                                  MoveConfig, OpenCloseConfig,
                                                  PhysicsConfig,
                                                  SceneConfiguration,
@@ -268,6 +268,18 @@ class TestConfigManager(unittest.TestCase):
 
         self.assertFalse(self.config_mngr.is_noise_enabled())
 
+    def test_timeout(self):
+        self.assertEqual(self.config_mngr.get_timeout(),
+                         self.config_mngr.TIMEOUT_DEFAULT)
+
+        self.config_mngr._config[
+            self.config_mngr.CONFIG_DEFAULT_SECTION
+        ][
+            self.config_mngr.CONFIG_TIMEOUT
+        ] = '50'
+
+        self.assertEqual(self.config_mngr.get_timeout(), 50)
+
 
 class TestSceneConfig(unittest.TestCase):
     def test_objects(self):
@@ -375,6 +387,10 @@ class TestSceneConfig(unittest.TestCase):
                 'stepBegin': 15
             }],
             'kinematic': True,
+            'lidAttachment': {
+                'stepBegin': 16,
+                'lidAttachmentObjId': 'test_container'
+            },
             'locationParent': 'parent_id',
             'mass': 12.34,
             'materials': ['material_1', 'material_2'],
@@ -524,6 +540,7 @@ class TestSceneConfig(unittest.TestCase):
         self.assertIsNone(object_1.ghosts)
         self.assertIsNone(object_1.hides)
         self.assertIsNone(object_1.kinematic)
+        self.assertIsNone(object_1.lid_attachment)
         self.assertIsNone(object_1.location_parent)
         self.assertIsNone(object_1.mass)
         self.assertIsNone(object_1.materials)
@@ -628,6 +645,10 @@ class TestSceneConfig(unittest.TestCase):
         )])
         self.assertEqual(object_2.hides, [SingleStepConfig(step_begin=15)])
         self.assertTrue(object_2.kinematic)
+        self.assertEqual(object_2.lid_attachment, LidConfig(
+            step_begin=16,
+            lid_attachment_obj_id='test_container'
+        ))
         self.assertEqual(object_2.location_parent, 'parent_id')
         self.assertEqual(object_2.mass, 12.34)
         self.assertListEqual(object_2.materials, ['material_1', 'material_2'])
@@ -709,7 +730,8 @@ class TestSceneConfig(unittest.TestCase):
             'metadata': {
                 'target': {'image': [0]},
                 'target_1': {'image': [1]},
-                'target_2': {'image': [2]}
+                'target_2': {'image': [2]},
+                'targets': [{'image': [3]}]
             }
         }
 
@@ -719,7 +741,8 @@ class TestSceneConfig(unittest.TestCase):
         self.assertEqual(actual.metadata, {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         })
 
     def test_retrieve_goal(self):
@@ -788,7 +811,8 @@ class TestSceneConfig(unittest.TestCase):
         goal = {'metadata': {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         }}
         goal = Goal(**goal)
         scene_config = SceneConfiguration(name="test", version=1, goal=goal)
@@ -796,30 +820,33 @@ class TestSceneConfig(unittest.TestCase):
         self.assertEqual(actual.metadata, {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         })
 
     def test_update_goal_target_image_img_as_str(self):
         goal = {'metadata': {
             'target': {'image': "[0]"},
             'target_1': {'image': "[1]"},
-            'target_2': {'image': "[2]"}
-        }
-        }
+            'target_2': {'image': "[2]"},
+            'targets': [{'image': "[3]"}]
+        }}
         goal = Goal(**goal)
         scene_config = SceneConfiguration(name="test", version=1, goal=goal)
         actual = scene_config.update_goal_target_image(scene_config.goal)
         self.assertEqual(actual.metadata, {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         })
 
     def test_update_goal_target_image_oracle(self):
         goal = {'metadata': {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         }}
         goal = Goal(**goal)
         scene_config = SceneConfiguration(name="test", version=1, goal=goal)
@@ -827,14 +854,16 @@ class TestSceneConfig(unittest.TestCase):
         self.assertEqual(actual.metadata, {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         })
 
     def test_update_goal_target_image_oracle_img_as_str(self):
         goal = {'metadata': {
             'target': {'image': "[0]"},
             'target_1': {'image': "[1]"},
-            'target_2': {'image': "[2]"}
+            'target_2': {'image': "[2]"},
+            'targets': [{'image': "[3]"}]
         }}
         goal = Goal(**goal)
         scene_config = SceneConfiguration(name="test", version=1, goal=goal)
@@ -842,7 +871,8 @@ class TestSceneConfig(unittest.TestCase):
         self.assertEqual(actual.metadata, {
             'target': {'image': [0]},
             'target_1': {'image': [1]},
-            'target_2': {'image': [2]}
+            'target_2': {'image': [2]},
+            'targets': [{'image': [3]}]
         })
 
 
