@@ -62,12 +62,14 @@ class TestController(unittest.TestCase):
                 'x': 0,
                 'y': 0
             },
+            recordTopDown=False,
             renderDepthImage=False,
             renderObjectImage=False,
             rotation={'y': 0.0},
             snapToGrid=False,
             teleportPosition=None,
             teleportRotation=None,
+            topDownImagePath=None,
             clockwise=True,
             lateral=0,
             straight=1
@@ -571,96 +573,6 @@ class TestController(unittest.TestCase):
         output = self.controller.step(mcs.Action.MOVE_AHEAD.value)
         self.assertIsNone(output)
 
-    def test_retrieve_action_list_at_step(self):
-        test_action_list = [
-            (mcs.Action.PASS.value, {}),
-            (mcs.Action.LOOK_UP.value, {'amount': 10}),
-            (mcs.Action.MOVE_AHEAD.value, {'amount': 0.1}),
-            (mcs.Action.PICKUP_OBJECT.value, {'objectId': 'ball'}),
-            (mcs.Action.PICKUP_OBJECT.value, {'objectId': 'duck'})
-        ]
-
-        # With no action list
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(),
-                0
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With empty action list
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[]),
-                0
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With empty nested action list
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[[]]),
-                0
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With test action list
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[test_action_list]),
-                0
-            ),
-            test_action_list
-        )
-        # With index greater than action list length
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[test_action_list]),
-                1
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With incorrect index
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[test_action_list, []]),
-                1
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With incorrect index
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[[], test_action_list]),
-                0
-            ),
-            GoalMetadata.DEFAULT_ACTIONS
-        )
-        # With correct index
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[[], test_action_list]),
-                1
-            ),
-            test_action_list
-        )
-        # Before last step
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[test_action_list], last_step=1),
-                0
-            ),
-            test_action_list
-        )
-        # On last step
-        self.assertEqual(
-            self.controller.retrieve_action_list_at_step(
-                mcs.GoalMetadata(action_list=[test_action_list], last_step=0),
-                0
-            ),
-            []
-        )
-
     def test_get_metadata_level(self):
         self.assertEqual('default', self.controller.get_metadata_level())
 
