@@ -495,14 +495,18 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (res, actual) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (res, actual) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
-        self.assertEqual(str(actual.goal), str(mcs.GoalMetadata()))
+        self.assertEqual(actual.goal.metadata, goal.metadata)
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.holes, [(0, 0), (1, 2), (9, 8)])
@@ -638,13 +642,21 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (res, actual) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (res, actual) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
+        self.assertEqual(actual.goal.metadata, {
+            'target': {},
+            'targets': [],
+        })
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.position, None)
@@ -695,14 +707,21 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (res, actual) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (res, actual) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
-        self.assertEqual(str(actual.goal), str(mcs.GoalMetadata()))
+        self.assertEqual(actual.goal.metadata, {
+            'target': {},
+            'targets': [],
+        })
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.position, None)
@@ -741,14 +760,21 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (res, actual) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (res, actual) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
-        self.assertEqual(str(actual.goal), str(mcs.GoalMetadata()))
+        self.assertEqual(actual.goal.metadata, {
+            'target': {},
+            'targets': [],
+        })
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.position, None)
@@ -787,13 +813,18 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (actual, res) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (actual, res) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
+        self.assertEqual(actual.goal.metadata, goal.metadata)
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.position, {'x': 0.12, 'y': -0.23, 'z': 4.5})
@@ -848,13 +879,18 @@ class TestControllerOutputHandler(unittest.TestCase):
         ], lava=[
             Vector2dInt(x=3, z=3), Vector2dInt(x=7, z=5), Vector2dInt(x=4, z=6)
         ]))
-        (res, actual) = coh.handle_output(mock_event, GoalMetadata(), 0, 1)
+        goal = GoalMetadata(metadata={
+            'target': {'id': 'target_id_1'},
+            'targets': [{'id': 'target_id_2'}, {'id': 'target_id_3'}]
+        })
+        (res, actual) = coh.handle_output(mock_event, goal, 0, 1)
 
         self.assertEqual(actual.action_list, GoalMetadata.DEFAULT_ACTIONS)
         self.assertEqual(actual.camera_aspect_ratio, (600, 400))
         self.assertEqual(actual.camera_clipping_planes, (0, 150))
         self.assertEqual(actual.camera_field_of_view, 42.5)
         self.assertEqual(actual.camera_height, 0.1234)
+        self.assertEqual(actual.goal.metadata, goal.metadata)
         self.assertEqual(actual.habituation_trial, None)
         self.assertEqual(actual.head_tilt, 12.34)
         self.assertEqual(actual.position, {'x': 0.12, 'y': -0.23, 'z': 4.5})
